<?php 
namespace Concrete\Package\C5dkTwentytwentyImage\Block\C5dkTwentytwentyImage;
use Loader;
use \File;
use Page;
use \Concrete\Core\Block\BlockController;
use Core;

defined('C5_EXECUTE') or die("Access Denied.");

class Controller extends BlockController {

    protected $btInterfaceWidth = 400;
    protected $btInterfaceHeight = 550;
    protected $btTable = 'btC5dkTwentytwentyImage';
    protected $btCacheBlockRecord = true;
    protected $btCacheBlockOutput = true;
    protected $btCacheBlockOutputOnPost = true;
    protected $btCacheBlockOutputForRegisteredUsers = true;
    protected $btWrapperClass = 'ccm-ui';
    protected $btExportFileColumns = array('fBeforeID','fAfterID');
    protected $btFeatures = array(  // C5DK TODO:
        'image'
    );

    /**
     * Used for localization. If we want to localize the name/description we have to include this
     */
    public function getBlockTypeDescription() {
        return t("Adds a before and after images with slide control.");
    }

    public function getBlockTypeName() {
        return t("C5DK TwentyTwenty Image");
    }

    public function registerViewAssets() {        
        $this->requireAsset('javascript', 'jquery');         
    }

    public function add() {
        $this->set('offset', '50');
    }
    
    public function view() {
        $fBefore = File::getByID($this->fBeforeID);
        if (!is_object($fBefore) || !$fBefore->getFileID()) {
            return false;
        }
        
        $fAfter = File::getByID($this->fBeforeID);
        if (!is_object($fAfter) || !$fAfter->getFileID()) {
            return false;
        }
        
        $imgPath = array();
        $imgPath['before'] = File::getRelativePathFromID($this->fBeforeID);
        $imgPath['after'] = File::getRelativePathFromID($this->fAfterID);
        $this->set('imgPath', $imgPath);
        $this->set('fBefore', $fBefore);
        $this->set('fAfter', $fAfter);
        
        $this->set('altText', $this->getAltText());
        $this->set('title', $this->getTitle());
        
        $this->set('orientation', ($this->getOrientation() == 0)? 'horizontal' : 'vertical');
        $this->set('offset', $this->getOffset());
    }

    public function getImageFeatureDetailFileObject() {
        // i don't know why this->fID isn't sticky in some cases, leading us to query
        // every damn time
        $db = Loader::db();
        $fBeforeID = $db->GetOne('select fBeforeID from btC5dkTwentytwentyImage where bID = ?', array($this->bID));
        if ($fBeforeID) {
            $fBefore = File::getByID($fBeforeID);
            if (is_object($fBefore) && !$fBefore->isError()) {
                return $fBefore;
            }
        }
    }

    function getFileBeforeID() {return $this->fBeforeID;}
    function getFileAfterID() {return $this->fAfterID;}
    
    public function getFileBeforeObject() {
        return File::getByID($this->fBeforeID);
    }
    public function getFileAfterObject() {
        return File::getByID($this->fAfterID);
    }
    
    function getAltText() {return $this->altText;}
    function getTitle() {return $this->title;}
    
    function getOrientation() {return $this->orientation;}
    function getOffset() {return $this->offset;}
    
    public function validate($data) {
        $e = Core::make('error');
        if (!$data['fBeforeID']) {
            $e->add(t('Before Image is required.'));
        }
        if (!$data['fAfterID']) {
            $e->add(t('After Image is required.'));
        }
        return $e;
    }

    public function save($args) {
        $args['fBeforeID'] = ($args['fBeforeID'] != '') ? $args['fBeforeID'] : 0;
        $args['fAfterID'] = ($args['fAfterID'] != '') ? $args['fAfterID'] : 0;
        parent::save($args);
    }

}
